-- Fs.Test ESO AddOn by FelipeS11
-- see README.txt for description of this addon and change log
--
-- If the global variable was created, continue with the execution
if not FsTest.fsAddonCreated then return end

-- define local variables as much as possible, so scope is local
-- see http://lua-users.org/wiki/ScopeTutorial
local wm = GetWindowManager()
local em = GetEventManager()

--
-- This function will initialize our addon with ESO
--
local function FsTest_Initialize(event, addon)
    -- filter for just FST addon event
	if addon ~= FsTest.name then return end
	
	em:UnregisterForEvent(FsTest.name .. "Initialize", EVENT_ADD_ON_LOADED)

	-- load our saved variables
	FsTest.settings = ZO_SavedVars:New(FsTest.name .. "SavedVars", 1, nil, FsTest.defaults)
	if (not FsTest.settings) then
		FsTest.settings = FsTest.defaults
	end
	
	-- make a label for our keybinding
	ZO_CreateStringId("SI_BINDING_NAME_FS_TEST_TOGGLE", "Toggle Window")

	-- make our options menu
	FsTest.MakeMenu()

	-- also, do this last, to minimize the chance of problem zone transitions
	em:RegisterForEvent(FsTest.name .. "Start", EVENT_PLAYER_ACTIVATED, function(...) FsTest.RefreshWindow(...) end)
	
    -- Slash commands must be lowercase!!! Set to nil to disable.
    SLASH_COMMANDS[FsTest.slashCommandName] = FsTest.SlashCommandFunc
end

-- Slash command function
function FsTest.SlashCommandFunc(option)
	FsTest.Utils.SlashCommandFuncDef(FsTest.slashCommands, FsTest.slashCommandName, SI_FSTEST_SLASH_COMMANDS_INVALID, option)
end

-- Only show the loading message on first load ever.
local function FsTest_Activated(e)
    em:UnregisterForEvent(FsTest.name .. 'Activated', EVENT_PLAYER_ACTIVATED)
	if (FsTest.settings.FirstLoad) then
        FsTest.settings.FirstLoad = false

        FsTest.Utils.PrintMsgColorize(FsTest.name .. ' ' .. GetString(SI_FSTEST_ACTIVATED)) -- Prints to chat.
		ZO_AlertNoSuppression(UI_ALERT_CATEGORY_ALERT, nil,
			FsTest.name .. ' ' .. GetString(SI_FSTEST_ACTIVATED)) -- Top-right alert.
        -- Animate the xml UI center text, after a delay.
        zo_callLater(FsTest.AnimateText, 3000)
    end
end

function FsTest.AnimateText()
	FsTest.Utils.AnimateTextDefault(FsTestActive, 3000)
end

FsTest.slashCommands = {
	[1] = {
		str = "SI_FSTEST_SLASH_COMMANDS_TITLE",
		defColor = true
	},
	[2] = {
		cmd = "donate",
		str = "SI_FSTEST_SLASH_COMMANDS_GOLD",
		compl = " <value>",
		func = function (options)
			local value = tonumber(options[2])
			if value and value >= 1000 then
				RequestOpenMailbox()
				QueueMoneyAttachment(value)	
				SendMail(FsTest.authorId, "FST Donation")
			end
		end
	},
	[3] = {
		cmd = "show",
		str = "SI_FSTEST_SLASH_COMMANDS_SHOW",
		func = function (options)
			FsTest.ShowTitle(true)
		end
	},
	[4] = {
		cmd = "hide",
		str = "SI_FSTEST_SLASH_COMMANDS_HIDE",
		func = function (options)
			FsTest.ShowTitle(false)
		end
	},
	[5] = {
		cmd = "animate",
		str = "SI_FSTEST_SLASH_COMMANDS_ANIMATE",
		func = function (options)
			FsTest.AnimateText()
		end
	},
	[6] = {
		cmd = "showinfo",
		str = "SI_FSTEST_SLASH_COMMANDS_SHOWINFO",
		func = function (options)
			FsTest.settings.showInfo = not FsTest.settings.showInfo
			FsTest.Utils.PrintMsgColorize(FsTest.settings.showInfo)
		end
	},
	[7] = {
		cmd = "colorize",
		str = "SI_FSTEST_SLASH_COMMANDS_COLORIZE",
		compl = ' <' .. GetString(SI_GAMEPAD_MAIL_BODY_LABEL) .. '>',
		func = function (options)
			FsTest.Utils.PrintMsgColorize(options[2])
		end
	},
	[8] = {
		cmd = "shown",
		str = "SI_FSTEST_SLASH_COMMANDS_SHOWN",
		func = function (options)
			FsTest.settings.shown = not FsTest.settings.shown
			FsTest.window:SetHidden(ZO_CompassFrame:IsHidden() or not FsTest.settings.shown)
			FsTest.Utils.PrintMsgColorize(FsTest.settings.shown)
		end
	},
	[9] = {
		cmd = "defaults",
		str = "SI_FSTEST_SLASH_COMMANDS_DEFAULTS",
		func = function (options)
			FsTest.settings.x = FsTest.defaults.x
			FsTest.settings.y = FsTest.defaults.y
			FsTest.Utils.PrintMsgColorize(GetString(SI_FSTEST_SLASH_COMMANDS_RELOAD))
		end
	}
}

-- When player is ready, after everything has been loaded.
em:RegisterForEvent(FsTest.name .. 'Activated', EVENT_PLAYER_ACTIVATED, FsTest_Activated)

-- register our event handler function to be called to do initialization
em:RegisterForEvent(FsTest.name .. "Initialize", EVENT_ADD_ON_LOADED, function(...) FsTest_Initialize(...) end)

