--
-- This file handles the window to display.
--
-- If the global variable was created, continue with the execution
if not FsTest.fsAddonCreated then return end

local wm = GetWindowManager()
--
-- This function will create the window to display
--
local function FsTest_MakeWindow()
	-- our primary window
	FsTest.window = wm:CreateTopLevelWindow(FsTest.name .. '_Window')
	
    local FsTest_Window = FsTest.window
	FsTest_Window:SetAnchor(TOPLEFT, GuiRoot, TOPLEFT, FsTest.settings.x, FsTest.settings.y)
	FsTest_Window:SetMovable(true)
	FsTest_Window:SetHidden(not FsTest.settings.shown)
	FsTest_Window:SetMouseEnabled(true)
	FsTest_Window:SetClampedToScreen(true)
	FsTest_Window:SetDimensions(0,0)
	FsTest_Window:SetResizeToFitDescendents(true)
	FsTest_Window:SetHandler("OnMoveStop", function()
		FsTest.settings.x = FsTest_Window:GetLeft()
		FsTest.settings.y = FsTest_Window:GetTop()
	end)
	
	-- give it a backdground (backdrop) for the frame
	FsTest_Window.bg = wm:CreateControl(FsTest.name .. "_Background", FsTest_Window, CT_BACKDROP)
	FsTest_Window.bg:SetAnchorFill(FsTest_Window)
	FsTest_Window.bg:SetCenterColor(0, 0, 0, FsTest.settings.alpha / 100)
	FsTest_Window.bg:SetEdgeColor(0, 0, 0, FsTest.settings.alpha / 100)
	FsTest_Window.bg:SetEdgeTexture(nil, 2, 2, 0, 0)
	FsTest_Window.bg:SetExcludeFromResizeToFitExtents(true)
	FsTest_Window.bg:SetDrawLayer(DL_BACKGROUND)
	
	-- give it a header
	FsTest_Window.title = wm:CreateControl(FsTest.name .. "_Title", FsTest_Window, CT_LABEL)
	FsTest_Window.title:SetAnchor(TOP, FsTest_Window, TOP, 0, 5)
	FsTest_Window.title:SetFont("EsoUi/Common/Fonts/Univers67.otf|18|soft-shadow-thin")
	FsTest_Window.title:SetColor(.9, .9, .7, 1)
	FsTest_Window.title:SetStyleColor(0, 0, 0, 1)
	FsTest_Window.title:SetText("Test")
	FsTest_Window.title:SetHidden(not FsTest.settings.showtitle)
	
	-- Give it a zone label
	FsTest_Window.zone = wm:CreateControl(FsTest.name .. "_Zone", FsTest_Window, CT_LABEL)
	if (FsTest.settings.showtitle) then
		FsTest_Window.zone:SetAnchor(TOP, FsTest_Window.title, BOTTOM, 0, 5)
	else
		FsTest_Window.zone:SetAnchor(TOP, FsTest_Window, TOP, 0, 5)
	end
	FsTest_Window.zone:SetFont("EsoUi/Common/Fonts/Univers67.otf|17|soft-shadow-thin")
	FsTest_Window.zone:SetColor(.9, .9, .7, 1)
	FsTest_Window.zone:SetStyleColor(0, 0, 0, 1)
	FsTest_Window.zone:SetText("Zone Name")

	-- make a container for the list entries
	FsTest_Window.entries = wm:CreateControl(FsTest.name .. "Entries", FsTest_Window, CT_CONTROL)
	FsTest_Window.entries:SetAnchor(TOP, FsTest_Window.zone, BOTTOM, 0, 0)
	FsTest_Window.entries:SetHidden(false)
	FsTest_Window.entries:SetResizeToFitDescendents(true)

	-- add a bit of padding
	FsTest_Window.entries:SetResizeToFitPadding(20, 10)
	
	-- hide our window when the compass frame gets hidden, if it's not hidden already
	if ZO_CompassFrame:IsHandlerSet("OnShow") then
		local oldHandler = ZO_CompassFrame:GetHandler("OnShow")
		ZO_CompassFrame:SetHandler("OnShow", function(...) oldHandler(...) FsTest.window:SetHidden(not FsTest.settings.shown) end)
	else
		ZO_CompassFrame:SetHandler("OnShow", function(...) FsTest.window:SetHidden(not FsTest.settings.shown) end)
	end
	if ZO_CompassFrame:IsHandlerSet("OnHide") then
		local oldHandler = ZO_CompassFrame:GetHandler("OnHide")
		ZO_CompassFrame:SetHandler("OnHide", function(...) oldHandler(...) FsTest.window:SetHidden(true) end)
	else
		ZO_CompassFrame:SetHandler("OnHide", function(...) FsTest.window:SetHidden(true) end)
	end
end
--
-- This function will populate the window with the new data
--
local function FsTest_PopulateWindow(zone)
	if FsTest.window == nil then FsTest_MakeWindow() end
	FsTest.window.zone:SetText(zone)
	
	local lowAlpha = 0.4
	local highAlpha = 1
	
	FsTest.window:SetHidden(ZO_CompassFrame:IsHidden() or not FsTest.settings.shown)
end

--
-- RefreshWindow() is a callback for EVENT_ZONE_CHANGED. 
-- It populates the window with data about the new zone.
-- It can show some information on the chat window
--
function FsTest.RefreshWindow()
	if (FsTest.settings.showInfo) then
		FsTest.Utils.PrintMsgColorize(GetString(SI_FSTEST_SLASH_SHOWINFO_TIME) .. '			' .. GetTimeString())
		FsTest.Utils.PrintMsgColorize(GetString(SI_FSTEST_SLASH_SHOWINFO_POSITION) .. '		' .. GetUnitWorldPosition('player'))
		if(GetUnitTitle('player') ~= '') then
			FsTest.Utils.PrintMsgColorize(GetString(SI_FSTEST_SLASH_SHOWINFO_TITLE) .. '		' .. GetUnitTitle('player'))
		end
		FsTest.Utils.PrintMsgColorize(GetString(SI_FSTEST_SLASH_SHOWINFO_NAME) .. '			' .. GetUnitName('player'))
	end
	
	FsTest.zone = GetUnitZone('player')
	
	FsTest_PopulateWindow(FsTest.zone)
end

--
-- Show or hide the window
--
function FsTest.ToggleWindow()
	local ishidden = FsTest.window:IsHidden()
	-- refresh the window if we're about to show it
	if ishidden then FsTest.RefreshWindow() end
	FsTest.settings.shown = ishidden
	FsTest.window:SetHidden(not ishidden)
end